<?php

namespace App\Controller;

use App\Entity\PieceCaracteristique;
use App\Entity\PieceModele;
use App\Form\PieceCaracteristiqueType;
use App\Repository\PieceCaracteristiqueRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/pieceCaracteristique')]
class PieceCaracteristiqueController extends AbstractController
{
    #[Route('/', name: 'app_piece_caracteristique')]
    public function index(PieceCaracteristiqueRepository $pieceCaracteristiqueRepository): Response
    {
        return $this->render('piece_caracteristique/index.html.twig', [
            'piece_caracteristiques' => $pieceCaracteristiqueRepository->findAll(),
        ]);
    }

    #[Route('/{id}', name: 'app_piece_caracteristique_show', requirements: ['id' => '\d+'])]
    public function show(int $id, PieceCaracteristiqueRepository $pieceCaracteristiqueRepository): Response
    {
        $pieceCaracteristique = $pieceCaracteristiqueRepository->find($id);

        if (!$pieceCaracteristique) {
            throw $this->createNotFoundException('La pièce caractéristique avec l\'identifiant '.$id.' n\'existe pas.');
        }
        return $this->render('piece_caracteristique/show.html.twig', [
            'piece_caracteristique' => $pieceCaracteristique,
        ]);
    }

    #[Route('/insert', name: 'app_piece_caracteristique_insert')]
    public function insert(EntityManagerInterface $entityManager): Response
    {
        $pieceModele = $entityManager->getRepository(PieceModele::class)->find(2);

        $pieceCaracteristique = new PieceCaracteristique();

        $pieceCaracteristique->setPieceModeleID($pieceModele);
        $pieceCaracteristique->setPieceFaceCommune("Pas drôle");
        $pieceCaracteristique->setPieceMasse(25);
        $pieceCaracteristique->setPieceTaille(100);
        $pieceCaracteristique->setPieceMateriau("C'est bien");

        $entityManager->persist($pieceCaracteristique);
        $entityManager->flush();

        return $this->redirectToRoute('app_piece_caracteristique_show', [
            'id' => $pieceCaracteristique->getId(),
        ], Response::HTTP_SEE_OTHER);
    }

    #[Route('/update/{id}', name: 'app_piece_caracteristique_update')]
    public function update(PieceCaracteristique $pieceCaracteristique, EntityManagerInterface $entityManager): Response
    {
        $pieceCaracteristique->setPieceFaceCommune("Marrant ça");
        $pieceCaracteristique->setPieceMasse(50);
        $pieceCaracteristique->setPieceTaille(75);
        $pieceCaracteristique->setPieceMateriau("Pas mal, pas mal");

        $entityManager->persist($pieceCaracteristique);
        $entityManager->flush();

        return $this->render('piece_caracteristique/show.html.twig', [
            'piece_caracteristique' => $pieceCaracteristique,
        ]);
    }

    #[Route('/delete/{id}', name: 'app_piece_caracteristique_delete')]
    public function delete(PieceCaracteristique $pieceCaracteristique, EntityManagerInterface $entityManager): Response
    {
            $entityManager->remove($pieceCaracteristique);
            $entityManager->flush();

        return $this->redirectToRoute('app_piece_caracteristique', [], Response::HTTP_SEE_OTHER);
    }
}
